# Personal Knowledge Base


# Prerequisites
1. Python >=3.12.7


# Installation 
1. mkdir pkb && cd pkb
2. python -m venv .venv
3. source .venv/bin/activate 
4. pip install pkb 
5. 
 

# To Launch 
1. uvicorn pkb.fast:app
2. 